import type { DifPexInputDescriptorToCredentials, DifPexCredentialsForRequest, DifPresentationExchangeDefinition, DifPresentationExchangeSubmission } from './models';
import type { AgentContext } from '../../agent';
import type { VerificationMethod } from '../dids';
import type { W3cVerifiableCredential, W3cVerifiablePresentation } from '../vc';
import type { PresentationSignCallBackParams } from '@sphereon/pex';
import { ClaimFormat } from '../vc';
import { DifPresentationExchangeSubmissionLocation } from './models';
export type ProofStructure = Record<string, Record<string, Array<W3cVerifiableCredential>>>;
export declare class DifPresentationExchangeService {
    private pex;
    getCredentialsForRequest(agentContext: AgentContext, presentationDefinition: DifPresentationExchangeDefinition): Promise<DifPexCredentialsForRequest>;
    /**
     * Selects the credentials to use based on the output from `getCredentialsForRequest`
     * Use this method if you don't want to manually select the credentials yourself.
     */
    selectCredentialsForRequest(credentialsForRequest: DifPexCredentialsForRequest): DifPexInputDescriptorToCredentials;
    validatePresentationDefinition(presentationDefinition: DifPresentationExchangeDefinition): void;
    validatePresentationSubmission(presentationSubmission: DifPresentationExchangeSubmission): void;
    validatePresentation(presentationDefinition: DifPresentationExchangeDefinition, presentation: W3cVerifiablePresentation): void;
    private formatValidated;
    /**
     * Queries the wallet for credentials that match the given presentation definition. This only does an initial query based on the
     * schema of the input descriptors. It does not do any further filtering based on the constraints in the input descriptors.
     */
    private queryCredentialForPresentationDefinition;
    private addCredentialToSubjectInputDescriptor;
    private getPresentationFormat;
    createPresentation(agentContext: AgentContext, options: {
        credentialsForInputDescriptor: DifPexInputDescriptorToCredentials;
        presentationDefinition: DifPresentationExchangeDefinition;
        /**
         * Defaults to {@link DifPresentationExchangeSubmissionLocation.PRESENTATION}
         */
        presentationSubmissionLocation?: DifPresentationExchangeSubmissionLocation;
        challenge?: string;
        domain?: string;
        nonce?: string;
    }): Promise<{
        verifiablePresentations: (import("../vc").W3cJsonLdVerifiablePresentation | import("../vc").W3cJwtVerifiablePresentation)[];
        presentationSubmission: import("@sphereon/pex-models").PresentationSubmission;
        presentationSubmissionLocation: DifPresentationExchangeSubmissionLocation;
    }>;
    private getSigningAlgorithmFromVerificationMethod;
    private getSigningAlgorithmsForPresentationDefinitionAndInputDescriptors;
    private getSigningAlgorithmForJwtVc;
    private getProofTypeForLdpVc;
    getPresentationSignCallback(agentContext: AgentContext, verificationMethod: VerificationMethod, vpFormat: ClaimFormat.LdpVp | ClaimFormat.JwtVp): (callBackParams: PresentationSignCallBackParams) => Promise<import("@sphereon/ssi-types").W3CVerifiablePresentation>;
    private getVerificationMethodForSubjectId;
}
